@@ -57,6 +57,11 @@ class CalibrateCmd(Command):
         parser.add_argument('--replay', '-r',
                             help="replay previous calibration",
                             action="store_true", default=False)
+
+        # --stub = False
+        parser.add_argument('--stub', '-s',
+                            help="use an identity calibration matrix (do not calibrate)",
+                            action="store_true", default=False)
         return parser
 
     def take_action(self, parsed_args):
@@ -106,6 +111,33 @@ class CalibrateCmd(Command):
         voltage_configs = meter_config["sensors"]["voltage"]
         current_configs = meter_config["sensors"]["current"]
         phases = meter_config["phases"]
+
+        ########
+        # If stub calibration is selected, confirm before generating the files
+        if parsed_args.stub:
+            response = input("Use an identity matrix instead of calibrating? (y/n) ")
+            if (response != 'y'):
+                print("Calibration cancelled, exiting")
+                exit(0)
+            print("generating a stub matrix")
+            # make sure the number of phases matches the number of current sensors
+            num_phases = meter_config["phases"]
+            num_sensors = len(current_configs["sensor_indices"])
+            if num_phases != num_sensors:
+                print("ERROR: number of sensors must equal phases for stub calibration")
+                return
+            if not calibration_config["has_neutral"]:
+                print("ERROR: select has_neutral for stub calibration")
+                return
+            calibration_config["sinefit_rotations"] = np.zeros(num_phases)
+            calibration_config["sensor_matrix"] = np.eye(num_sensors)
+            calibration_config["current_matrix"] = np.eye(num_phases)
+            calibrate_finalize.run(meter_config)
+
+            print("to (re)start data capture run [sudo service joule (re)start]")
+            print("***ALL DONE***")
+            return
+
         ########
         # Display config values for user confirmation
         print("")
@@ -132,8 +164,8 @@ class CalibrateCmd(Command):
         # print calibration information
         print("  + Calibration load is %dW and will run for %d seconds" % \
               (calibration_config["watts"], calibration_config["duration"]))
-        print("  + Calibration load is has pattern: %f seconds ON and %f seconds OFF"%\
-            (calibration_config["on_duration"], calibration_config["off_duration"]))
+        print("  + Calibration load is has pattern: %f seconds ON and %f seconds OFF" % \
+              (calibration_config["on_duration"], calibration_config["off_duration"]))
         print("  + The reference voltage is %dV rms" % \
               voltage_configs["nominal_rms_voltage"])
         print("  + The meter serial number is [%s]" % meter_config["serial_number"])
