@@ -328,6 +328,8 @@ class RawToPrep(CompositeModule):
             'min_freq': freq-10,
             'max_freq': freq+10,
             'min_amp': amp,
+            'sfit4_iters': 7, # default from previous hard coded implementation
+            'cache_size': 60 # default 1 second of data @ 60 Hz
         }
 
     def _build_prep_configs(self, meter, merge_output, polar):
@@ -378,7 +380,8 @@ class RawToPrep(CompositeModule):
             'merge': merge_output,
             'polar': polar,
             'samp_freq': _compute_sampling_frequency(meter),
-            'goertzel': _compute_goertzel(meter)
+            'goertzel': _compute_goertzel(meter),
+            'cache_size': 60 # default 1 second of data @ 60 Hz
         }
 
     
