@@ -2,7 +2,9 @@ import numpy as np
 import asyncio
 import json
 
-from joule import FilterModule, yesno
+from joule import FilterModule
+from joule.utilities import yesno
+from joule.models.pipes import EmptyPipe
 from nilm.filters.helpers import FilterError
 
 
@@ -17,7 +19,7 @@ ARGS_DESC = """
 :url:
   http://git.wattsworth.net/wattsworth/nilm.git
 :description:
-  convert raw data to I/V
+  convert raw data to current and voltage
 :usage:
   Convert data collected by nilm-reader into current (I) and voltage (V)
  
@@ -68,7 +70,7 @@ ARGS_DESC = """
 :stream_configs:
   #output (noncontact)#
      [Main]
-     name = I/V
+     name = IV
      path = /path/to/output
      datatype = float32
      keep = 1w
@@ -85,7 +87,7 @@ ARGS_DESC = """
 
   #output (contact)#
      [Main]
-     name = I/V
+     name = IV
      path = /path/to/output
      datatype = float32
      keep = 1w
@@ -141,10 +143,13 @@ class Reconstructor(FilterModule):
         total_rows_processed = 0
         dc_offsets = None
         current_matrix = np.array(parsed_args.current_matrix)
-        while(True):
+        while True:
             await asyncio.sleep(0.1)
-            sarray_in = await input.read()
-            if(dc_offsets is None):
+            try:
+                sarray_in = await input.read()
+            except EmptyPipe:
+                break
+            if dc_offsets is None:
                 dc_offsets = np.mean(sarray_in['data'], axis=0)
 
             output_len = len(sarray_in)
@@ -153,6 +158,8 @@ class Reconstructor(FilterModule):
                 output_len = len(sarray_in) - size
                 if(output_len <= 0):
                     # we need more data to integrate
+                    if input.closed:
+                        break
                     continue
             sarray_out = np.zeros(output_len,
                                   dtype=output.dtype)
@@ -185,6 +192,7 @@ class Reconstructor(FilterModule):
             input.consume(rows_processed)
             if(nrows > 0 and total_rows_processed >= nrows):
                 break
+        await output.close()
 
     def _verify_no_gaps(self, ts, max_gap):
         """ if there are gaps in timetsamps, raise error"""
