@@ -4,6 +4,10 @@ import yaml
 
 from nilm.meter.utils import MeterConfigurationError
 
+DEFAULTS = {
+    'voltage_scale': 1.0
+    }
+
 
 def load_calibration(directory, meter):
     cal_file = os.path.join(directory, meter['name'] + '.yml')
@@ -12,14 +16,17 @@ def load_calibration(directory, meter):
         return
     try:
         with open(cal_file, 'r') as f:
-            cal = yaml.load(f)
+            cal = yaml.safe_load(f)
+            # set up defaults if anything is missing
+            cal = {**DEFAULTS, **cal}
     except Exception as e:
         raise MeterConfigurationError(str(e)) from e
 
     meter['calibrated'] = True
     if('calibration' in meter):
-        #prefer hard coded values in meters.yml over cal file
+        # prefer hard coded values in meters.yml over cal file
         meter['calibration'] = {**cal,
                                 **meter['calibration']}
     else:
         meter['calibration'] = cal
+
