@@ -49,7 +49,7 @@ def _load_meter_file(meter_file):
     # load the meters file
     try:
         with open(meter_file, 'r') as f:
-            meters = yaml.load(f)
+            meters = yaml.safe_load(f)
     except FileNotFoundError:
         raise MeterConfigurationError(
             "can't load meters file at [%s], is it missing?" % meter_file)
