@@ -6,6 +6,7 @@ from joule import ReaderModule
 from joule.utilities import yesno
 from .serialcapture import SerialCapture
 from .ethstreamcapture import EthstreamCapture
+from .nerdjackcapture import NerdjackCapture
 from .errors import CaptureError
 
 ARGS_DESC = """
@@ -24,7 +25,7 @@ ARGS_DESC = """
   | Arguments            | Default | Description
   |----------------------|---------|-------------------------------------------------
   |``max-gap``           | 10      | max seconds between sample ts and clock
-  |``align-with-clock`` | yes      | [**yes**,**no**] align samples with system clock
+  |``align-with-clock``  | yes     | [**yes**,**no**] align samples with system clock
   |``meter-type``        | --      | [**contact**,**noncontact**] required parameter
   |``ip-address``        | 192.168.1.209      | contact meter IP address
   |``tty``               | --      | non-contact meter serial port
@@ -125,6 +126,16 @@ class Capture(ReaderModule):
                             required=True,
                             dest="meter_type",
                             choices=["contact", "noncontact"])
+        # --daq-type
+        parser.add_argument("--daq-type",
+                            default="labjack",
+                            dest="daq_type",
+                            choices=["labjack", "nerdjack"])
+        # --filter-index
+        parser.add_argument("--filter-index",
+                            type = int,
+                            dest="filter_index",
+                            default = None)
         # --ip-address
         parser.add_argument("--ip-address",
                             default="192.168.1.209")
@@ -147,7 +158,10 @@ class Capture(ReaderModule):
 
                 self.my_capture = SerialCapture(parsed_args.tty)
             else:
-                self.my_capture = EthstreamCapture(parsed_args.ip_address)
+                if(parsed_args.daq_type == "labjack"):
+                    self.my_capture = EthstreamCapture(parsed_args.ip_address)
+                elif(parsed_args.daq_type == "nerdjack"):
+                    self.my_capture = NerdjackCapture(parsed_args.ip_address,parsed_args.filter_index)
             await self.my_capture.run(output,
                                       max_gap=parsed_args.max_gap,
                                       align=parsed_args.align,
@@ -169,4 +183,4 @@ def main():
 
     
 if __name__ == "__main__":
-    main()
+    main()
\ No newline at end of file
