@@ -92,11 +92,12 @@ class SerialCapture():
             exit(1)  # can't recover
 
         if (self.data_ts + self.max_gap) < self.clock_ts:
-            print("Skipping data timestamp forward from "
-                  "%s to %s to match clock time\n" % (
+            print("Data is coming in too slow: data time "
+                  "is %s but clock time is %s" % (
                       timestamp_to_human(self.data_ts),
                       timestamp_to_human(self.clock_ts)))
-            self.data_ts = self.clock_ts
+            exit(1)
+            #self.data_ts = self.clock_ts
 
     def _realign(self):
         # read bytes from serial until we hit an alignment sequence
